

FITSKeyword
===================================================

.. currentmodule:: msumastro.header_processing.fitskeyword

.. autoclass:: FITSKeyword
   :show-inheritance:

   
     
   

   
   

   .. rubric:: Attributes Summary

   .. autosummary::
   
      ~FITSKeyword.name
      ~FITSKeyword.names
      ~FITSKeyword.synonyms

   
   

   
   

   .. rubric:: Methods Summary

   .. autosummary::
   
      ~FITSKeyword.add_to_header
      ~FITSKeyword.history_comment
      ~FITSKeyword.set_value_from_header

   
   

   
   

   .. rubric:: Attributes Documentation

   
   .. autoattribute:: name
   .. autoattribute:: names
   .. autoattribute:: synonyms

   
   

   
   

   .. rubric:: Methods Documentation

   
   .. automethod:: add_to_header
   .. automethod:: history_comment
   .. automethod:: set_value_from_header

   
   